# Django

### Create a Project:

```shell
bomiot project <project_name>
```

### Create a Django APP:

```shell
bomiot new <app_name>
```

- Then you can write your Django application within this app.

---

## References

- [Django Official Documentation](https://docs.djangoproject.com/en/4.2/)
- [Django GitHub](https://github.com/django/django)

---

For more advanced usage (such as multi-environment management, plugin extensions, etc.), refer to the official documentation or community resources.